==> huaweicloudsdkcdn-3.1.41-py2.py3-none-any.whl: huaweicloudsdkcdn/v1/model/delete_tags_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteTagsRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'resource_id': 'str',
        'tags': 'list[str]'
    }

    attribute_map = {
        'resource_id': 'resource_id',
        'tags': 'tags'
    }

    def __init__(self, resource_id=None, tags=None):
        """DeleteTagsRequestBody

        The model defined in huaweicloud sdk

        :param resource_id: 资源id
        :type resource_id: str
        :param tags: 键列表
        :type tags: list[str]
        """
        
        

        self._resource_id = None
        self._tags = None
        self.discriminator = None

        self.resource_id = resource_id
        self.tags = tags

    @property
    def resource_id(self):
        """Gets the resource_id of this DeleteTagsRequestBody.

        资源id

        :return: The resource_id of this DeleteTagsRequestBody.
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """Sets the resource_id of this DeleteTagsRequestBody.

        资源id

        :param resource_id: The resource_id of this DeleteTagsRequestBody.
        :type resource_id: str
        """
        self._resource_id = resource_id

    @property
    def tags(self):
        """Gets the tags of this DeleteTagsRequestBody.

        键列表

        :return: The tags of this DeleteTagsRequestBody.
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this DeleteTagsRequestBody.

        键列表

        :param tags: The tags of this DeleteTagsRequestBody.
        :type tags: list[str]
        """
        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteTagsRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcdn-3.1.116-py2.py3-none-any.whl: huaweicloudsdkcdn/v1/model/delete_tags_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteTagsRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'resource_id': 'str',
        'tags': 'list[str]'
    }

    attribute_map = {
        'resource_id': 'resource_id',
        'tags': 'tags'
    }

    def __init__(self, resource_id=None, tags=None):
        """DeleteTagsRequestBody

        The model defined in huaweicloud sdk

        :param resource_id: 资源id。  &gt; 域名ID
        :type resource_id: str
        :param tags: 键列表
        :type tags: list[str]
        """
        
        

        self._resource_id = None
        self._tags = None
        self.discriminator = None

        self.resource_id = resource_id
        self.tags = tags

    @property
    def resource_id(self):
        """Gets the resource_id of this DeleteTagsRequestBody.

        资源id。  > 域名ID

        :return: The resource_id of this DeleteTagsRequestBody.
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """Sets the resource_id of this DeleteTagsRequestBody.

        资源id。  > 域名ID

        :param resource_id: The resource_id of this DeleteTagsRequestBody.
        :type resource_id: str
        """
        self._resource_id = resource_id

    @property
    def tags(self):
        """Gets the tags of this DeleteTagsRequestBody.

        键列表

        :return: The tags of this DeleteTagsRequestBody.
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this DeleteTagsRequestBody.

        键列表

        :param tags: The tags of this DeleteTagsRequestBody.
        :type tags: list[str]
        """
        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteTagsRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
